Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(653)

Unified Diff: components/signin/core/common/signin_switches.cc

Issue 1344443002: Implement new password separated sign in flow for chrome desktop. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address review comments Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/signin/core/common/signin_switches.cc
diff --git a/components/signin/core/common/signin_switches.cc b/components/signin/core/common/signin_switches.cc
index 2e1950ca103f2724286332083138aa40f9dc649b..5efd7bf21430febbabbd40a17086755dcbffc9dd 100644
--- a/components/signin/core/common/signin_switches.cc
+++ b/components/signin/core/common/signin_switches.cc
@@ -19,7 +19,10 @@ const char kDisableNewProfileManagement[] = "disable-new-profile-management";
// Disables the new avatar menu, forcing the top-corner avatar button.
const char kDisableNewAvatarMenu[] = "disable-new-avatar-menu";
-// Disable sending signin scoped device id to LSO with refresh token request.
+// Disables new gaia password-separated sign in flow.
+const char kDisableNewGaiaSigninFlow[] = "disable-new-gaia-signin-flow";
+
+// Disables sending signin scoped device id to LSO with refresh token request.
const char kDisableSigninScopedDeviceId[] = "disable-signin-scoped-device-id";
// Enables consistent identity features.
@@ -29,13 +32,16 @@ const char kEnableAccountConsistency[] = "enable-account-consistency";
// webview-based flow.
const char kEnableIframeBasedSignin[] = "enable-iframe-based-signin";
-// Enable the new avatar menu and the User Manager.
+// Enables the new avatar menu and the User Manager.
const char kEnableNewAvatarMenu[] = "enable-new-avatar-menu";
+// Enables new gaia password-separated sign in flow.
+const char kEnableNewGaiaSigninFlow[] = "enable-new-gaia-signin-flow";
+
// Enables new profile management system, including lock mode.
const char kEnableNewProfileManagement[] = "new-profile-management";
-// Enable sending EnableRefreshTokenAnnotationRequest.
+// Enables sending EnableRefreshTokenAnnotationRequest.
extern const char kEnableRefreshTokenAnnotationRequest[] =
"enable-refresh-token-annotation-request";

Powered by Google App Engine
This is Rietveld 408576698